# Requirement Index

Track all project requirements here.

## Status Legend
- `[ ]` - Not started
- `[/]` - In progress  
- `[x]` - Completed
- `[!]` - Blocked

## Active Requirements

| ID | Priority | Status | Title | Assigned |
|----|----------|--------|-------|----------|
| REQ-001 | P2 | [ ] | Example requirement | - |

## Backlog

<!-- Add future requirements here -->

## Completed

<!-- Move completed requirements here -->

---

*Use `skill/req-create/` to add new requirements.*
